import os
from stresser.modules import *


def main():
    my_config = parse_input()

    SOLUTION_PATH = my_config['SOLUTION_PATH']
    DUMMY_PATH = my_config['DUMMY_PATH']
    GENERATOR_PATH = my_config['GENERATOR_PATH']
    NTESTS = my_config['NTESTS']
    SAVE_TESTS = my_config['SAVE_TESTS']
    CHECKER_TYPE = my_config['CHECKER_TYPE']

    if not os.path.exists('stresser_data'):
        os.mkdir('stresser_data')
    if not os.path.exists(f"stresser_data{os.sep}files"):
        os.mkdir(f"stresser_data{os.sep}files")
    if not os.path.exists(f"stresser_data{os.sep}tests"):
        os.mkdir(f"stresser_data{os.sep}tests")
    clean(tests=True)
    clean(files=True)


    launch_solution = get_launcher(SOLUTION_PATH, "solution")
    launch_dummy = get_launcher(DUMMY_PATH, "dummy")
    launch_generator = get_launcher(GENERATOR_PATH, "generator")

    cur_checker = None
    if CHECKER_TYPE == 'base':
        cur_checker = base_check
    elif CHECKER_TYPE == 'base_with_format':
        cur_checker = base_with_format_check


    for test_num in range(1, NTESTS + 1):
        if not SAVE_TESTS:
            clean(tests=True)
        test_path = f"stresser_data{os.sep}tests{os.sep}{test_num}_in.txt"
        dummy_out_path = f"stresser_data{os.sep}tests{os.sep}{test_num}_out_dummy.txt"
        solution_out_path = f"stresser_data{os.sep}tests{os.sep}{test_num}_out_solution.txt"

        launch_generator(out_path=test_path, flags=str(test_num))
        launch_dummy(test_path, dummy_out_path)
        launch_solution(test_path, solution_out_path)

        f_dummy_out = open(dummy_out_path, "r")
        dummy_out = f_dummy_out.read()
        f_dummy_out.close()

        f_solution_out = open(solution_out_path, "r")
        solution_out = f_solution_out.read()
        f_solution_out.close()

        

        if cur_checker(dummy_out, solution_out):
            print(f"test {test_num} OK")
        else:
            target_test = open(test_path)
            print(
                f"""
    test {test_num} WA
    ------------------------------
    INPUT:
    {target_test.read()}
    --------------------
    RIGHT:
    {dummy_out}
    --------------------
    WRONG:
    {solution_out}
    ------------------------------
        """
            )
            target_test.close()
            break

    if not SAVE_TESTS:
        clean(files=True, tests=True)


if __name__ == '__main__':
    main()


import os

pref = '/home/gingersamurai/coding/projects/py-stresser/test/tests'
os.chdir(pref)

cnt = len(os.listdir('.'))

for now_case in os.listdir('.'):
    os.chdir(f'{pref}/{now_case}')

    with open('args') as f:
        args = f.read()

    print(F"{'_'*20}[{now_case}] START TESTING{'_'*20}\n\n\n")
    os.system(f'stresser {args}')
    print(F"\n\n\n{'_'*20}[{now_case}] FINISH TESTING{'_'*20}\n\n\n")

print(f"DONE {cnt} testcases\n\n\n\n\n")



import os
import sys

# очищение файлов
def clean(files = False, tests = False):
    if tests:
        tests_path = f"stresser_data{os.sep}tests"
        for test_file in os.listdir(tests_path):
            os.remove(f"{tests_path}{os.sep}{test_file}")
    if files:
        files_path = f"stresser_data{os.sep}files"
        for file_file in os.listdir(files_path):
            os.remove(f"{files_path}{os.sep}{file_file}")
    if files and tests:
        os.rmdir(f"stresser_data{os.sep}tests")
        os.rmdir(f"stresser_data{os.sep}files")
        os.rmdir("stresser_data")

# компиляция файла и возвращение функции запуска
def get_launcher(path: str, type: str, flags: str = ""):
    exst = path[path.find('.'):]
    respath = f"stresser_data{os.sep}files{os.sep}{type}"
    launcher: str
    if exst == '.py':
        respath += ".py"
        command: str
        if os.name == 'posix':
            launcher = 'python3'
            command = 'cp'
        else:
            launcher = 'python'
            command = 'copy'
        os.system(f"{command} {path} {flags} {respath}")
    elif exst == '.c':
        launcher = ''
        if os.name == 'posix':
            respath += '.out'
        else:
            respath == '.exe'
        os.system(f"gcc {path} {flags} -o {respath}")
    elif exst == '.cpp':
        launcher = ''
        if os.name == 'posix':
            respath += '.out'
        else:
            respath == '.exe'
        os.system(f"g++ {path} {flags} -o {respath}")


    def launch(in_path: str = None, out_path: str = None, flags = ""):
        if in_path != None:
            in_path = '< ' + in_path
        else:
            in_path = ''
        if out_path != None:
            out_path = '> ' + out_path
        else:
            out_path = ''
        os.system(f"{launcher} {respath} {flags} {in_path} {out_path}")
    
    return launch




from setuptools import find_packages, setup

with open("README.md") as file:
    read_me_description = file.read()


setup(
    name='py-stresser',
    version='2.0.0b1',
    author='gingersamurai',
    author_email='nazimmalyshev47@gmail.com',
    description='package for stress testing',
    long_description_content_type="text/markdown",
    long_description=read_me_description,
    url='https://github.com/gingersamurai/stresser',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'stresser=stresser.__main__:main'
        ]
    },
    include_package_data=True
)

